package com.ynet.life.loaf.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.action.LifeJDBCAction;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.LoafTools;
import com.ynet.life.loaf.jdbc.LoafQueryFactory;
import com.ynet.life.loaf.jdbc.LoafQueryInterface;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_loaf_action.jar:com/ynet/life/loaf/action/QueryDataDetailUsingSQLForTokenAction.class */
public class QueryDataDetailUsingSQLForTokenAction extends LifeJDBCAction {
    private static final String FIELD_SEPERATOR = "||";
    private String querySql;
    private String parmSql;
    private List outputFields = new ArrayList();
    private String sortParam;

    public String execute(Context context) throws GENEException {
        try {
            try {
                List input = new LinkedList();
                String finalSQL = LoafTools.parseQuerySql(context, this.querySql, input);
                if (context.get(this.parmSql) != null) {
                    String parmSql = context.get(this.parmSql).toString();
                    finalSQL = String.valueOf(finalSQL) + " AND " + parmSql;
                }
                LoafQueryInterface query = LoafQueryFactory.getNewQuery("", this.sortParam, finalSQL);
                PreparedStatement ps = null;
                ResultSet resultSet = null;
                try {
                    try {
                        Connection connection = LifeDBAccess.getConnection();
                        ps = query.getQueryStatement(connection, input);
                        resultSet = ps.executeQuery();
                        int dateSize = this.outputFields.size();
                        if (resultSet.next()) {
                            for (int i = 1; i <= dateSize; i++) {
                                String dataFieldValue = resultSet.getString(i);
                                context.put((String) this.outputFields.get(i - 1), dataFieldValue);
                                Trace.logDebug("LOAF", "输出参数--->\n".concat(String.valueOf(dataFieldValue)));
                            }
                            LifeDBAccess.cleanResources(ps, resultSet);
                            LifeDBAccess.releaseConnection(connection);
                            return "0";
                        }
                        LifeDBAccess.releaseConnection(connection);
                        return QueryDataListAction.NO_DATA_FOUND;
                    } finally {
                        LifeDBAccess.cleanResources(ps, resultSet);
                    }
                } catch (SQLException ex) {
                    throw new TranFailException("EBLN0000", ex);
                }
            } catch (GENEException empe) {
                Trace.logError("LOAF", empe.getMessage(), empe);
                throw empe;
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection((Connection) null);
            throw th;
        }
    }

    public void setSortParam(String sortParam) {
        this.sortParam = sortParam;
    }

    public void setOutputFields(String outputFields) {
        StringTokenizer toke = new StringTokenizer(outputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            this.outputFields.add(input);
        }
    }

    public String getQuerySql() {
        return this.querySql;
    }

    public void setQuerySql(String querySql) {
        this.querySql = querySql;
    }

    public String getParmSql() {
        return this.parmSql;
    }

    public void setParmSql(String parmSql) {
        this.parmSql = parmSql;
    }
}
